==> rosegarden-21.06.1.tar.bz2: rosegarden-21.06.1/src/commands/edit/CollapseNotesCommand.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2021 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef RG_COLLAPSENOTESCOMMAND_H
#define RG_COLLAPSENOTESCOMMAND_H

#include "document/BasicSelectionCommand.h"
#include <QString>
#include <QCoreApplication>


class Collapse;


namespace Rosegarden
{

class EventSelection;


class CollapseNotesCommand : public BasicSelectionCommand
{
    Q_DECLARE_TR_FUNCTIONS(Rosegarden::CollapseNotesCommand)

public:
    CollapseNotesCommand(EventSelection &selection) :
        BasicSelectionCommand(getGlobalName(), selection, true),
        m_selection(&selection) { }

    static QString getGlobalName() { return tr("Collapse &Equal-Pitch Notes"); }

protected:
    void modifySegment() override;

private:
    EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
};


// Set the (numerical) property of a selection according given pattern.
//

}

#endif

==> rosegarden_21.12.orig.tar.bz2: rosegarden-21.12/src/commands/edit/CollapseNotesCommand.h <==

/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2021 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef RG_COLLAPSENOTESCOMMAND_H
#define RG_COLLAPSENOTESCOMMAND_H

#include "document/BasicSelectionCommand.h"
#include <QString>
#include <QCoreApplication>


class Collapse;


namespace Rosegarden
{

class EventSelection;


class CollapseNotesCommand : public BasicSelectionCommand
{
    Q_DECLARE_TR_FUNCTIONS(Rosegarden::CollapseNotesCommand)

public:
    CollapseNotesCommand(EventSelection &selection, bool splitAtBars) :
        BasicSelectionCommand(getGlobalName(), selection, true),
        m_selection(&selection),
        m_splitAtBars(splitAtBars) { }

    static QString getGlobalName() { return tr("Collapse &Equal-Pitch Notes"); }

protected:
    void modifySegment() override;

private:
    EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
    bool m_splitAtBars;
};


// Set the (numerical) property of a selection according given pattern.
//

}

#endif
